@@ -53,7 +53,7 @@ void MainClass::run()
     }
     else
     {
-        m_position = new GpsPos(this, g_runs, g_limit, g_lknv, g_sat, g_fout, g_posm, g_interval, g_date, g_time, g_log, g_newtrack);
+        m_position = new GpsPos(this, g_runs, g_limit, g_lknv, g_sat, g_fout, g_posm, g_interval, g_date, g_time, g_log, g_newtrack, g_script);
         connect(m_position, SIGNAL(finished()),this, SLOT(quit()));
     }
 
